@@ -46,6 +46,11 @@ def app():
         capture_message("hi")
         return "ok"
 
+    @app.route("/message/<int:message_id>")
+    def hi_with_id(message_id):
+        capture_message("hi again")
+        return "ok"
+
     return app
 
 
@@ -74,10 +79,22 @@ def test_has_context(sentry_init, app, capture_events):
 
 
 @pytest.mark.parametrize(
-    "transaction_style,expected_transaction", [("endpoint", "hi"), ("url", "/message")]
+    "url,transaction_style,expected_transaction,expected_source",
+    [
+        ("/message", "endpoint", "hi", "component"),
+        ("/message", "url", "/message", "route"),
+        ("/message/123456", "endpoint", "hi_with_id", "component"),
+        ("/message/123456", "url", "/message/<int:message_id>", "route"),
+    ],
 )
 def test_transaction_style(
-    sentry_init, app, capture_events, transaction_style, expected_transaction
+    sentry_init,
+    app,
+    capture_events,
+    url,
+    transaction_style,
+    expected_transaction,
+    expected_source,
 ):
     sentry_init(
         integrations=[
@@ -87,11 +104,12 @@ def test_transaction_style(
     events = capture_events()
 
     client = app.test_client()
-    response = client.get("/message")
+    response = client.get(url)
     assert response.status_code == 200
 
     (event,) = events
     assert event["transaction"] == expected_transaction
+    assert event["transaction_info"] == {"source": expected_source}
 
 
 @pytest.mark.parametrize("debug", (True, False))
